# (generated with --quick)

import uuid
from plain import models
from plain.models import migrations
from typing import Any

class Migration(Any):
    dependencies: list[tuple[str, str]]
    operations: list
